/* $TOG: XmStrDefsI.ht /main/1 1997/06/18 17:50:36 samborn $ */
#ifndef _XmStrDefsI_h_
#define _XmStrDefsI_h_

#include <Xm/XmStrDefs.h>

#ifdef __cplusplus
extern "C" {
#endif

/* $TOG: makestrs.c /main/11 1998/02/06 11:24:15 kaleb $ */
/* This file is automatically generated. */
/* Default ABI version -- Do not edit */
/* TOG: xmstring.list /main/5 1997/06/20 08:37:02 samborn */

#ifdef XMSTRINGDEFINES
#define XmIATOM_PAIR "ATOM_PAIR"
#define XmIAVERAGE_WIDTH "AVERAGE_WIDTH"
#define XmIBACKGROUND "BACKGROUND"
#define XmICHARACTER_POSITION "CHARACTER_POSITION"
#define XmICLASS "CLASS"
#define XmICOLUMN_NUMBER "COLUMN_NUMBER"
#define XmIDONE "DONE"
#define XmIFOREGROUND "FOREGROUND"
#define XmIHOST_NAME "HOST_NAME"
#define XmILINE_NUMBER "LINE_NUMBER"
#define XmILIST_LENGTH "LIST_LENGTH"
#define XmIMODULE "MODULE"
#define XmINAME "NAME"
#define XmINone "None"
#define XmIODIF "ODIF"
#define XmIOWNER_OS "OWNER_OS"
#define XmIPDM_EXIT_CANCEL "PDM_EXIT_CANCEL"
#define XmIPDM_EXIT_ERROR "PDM_EXIT_ERROR"
#define XmIPDM_EXIT_OK "PDM_EXIT_OK"
#define XmIPDM_REPLY "PDM_REPLY"
#define XmIPDM_START "PDM_START"
#define XmIPDM_START_ERROR "PDM_START_ERROR"
#define XmIPDM_START_OK "PDM_START_OK"
#define XmIPDM_START_PXAUTH "PDM_START_PXAUTH"
#define XmIPDM_START_VXAUTH "PDM_START_VXAUTH"
#define XmIPIXEL "PIXEL"
#define XmIPIXEL_SIZE "PIXEL_SIZE"
#define XmIPROCEDURE "PROCEDURE"
#define XmIPROCESS "PROCESS"
#define XmIRESOLUTION_Y "RESOLUTION_Y"
#define XmISPAN "SPAN"
#define XmITASK "TASK"
#define XmIUSER "USER"
#define XmIWM_DELETE_WINDOW "WM_DELETE_WINDOW"
#define XmI_MOTIF_CURRENT_TIME "_MOTIF_CURRENT_TIME"
#define XmI_MOTIF_DRAG_ATOMS "_MOTIF_DRAG_ATOMS"
#define XmI_MOTIF_DRAG_INITIATOR_INFO "_MOTIF_DRAG_INITIATOR_INFO"
#define XmI_MOTIF_DRAG_PROXY_WINDOW "_MOTIF_DRAG_PROXY_WINDOW"
#define XmI_MOTIF_DRAG_RECEIVER_INFO "_MOTIF_DRAG_RECEIVER_INFO"
#define XmI_MOTIF_DRAG_TARGETS "_MOTIF_DRAG_TARGETS"
#define XmI_MOTIF_DRAG_WINDOW "_MOTIF_DRAG_WINDOW"
#define XmI_MOTIF_INITIATOR "_MOTIF_INITIATOR"
#define XmI_MOTIF_RECEIVER "_MOTIF_RECEIVER"
#define XmI_MOTIF_SELECTION_TEXT "_MOTIF_SELECTION_TEXT"
#else
externalref _XmConst char _XmStringsI[];
#ifndef XmIATOM_PAIR
#define XmIATOM_PAIR ((char*)&_XmStringsI[0])
#endif
#ifndef XmIAVERAGE_WIDTH
#define XmIAVERAGE_WIDTH ((char*)&_XmStringsI[10])
#endif
#ifndef XmIBACKGROUND
#define XmIBACKGROUND ((char*)&_XmStringsI[24])
#endif
#ifndef XmICHARACTER_POSITION
#define XmICHARACTER_POSITION ((char*)&_XmStringsI[35])
#endif
#ifndef XmICLASS
#define XmICLASS ((char*)&_XmStringsI[54])
#endif
#ifndef XmICOLUMN_NUMBER
#define XmICOLUMN_NUMBER ((char*)&_XmStringsI[60])
#endif
#ifndef XmIDONE
#define XmIDONE ((char*)&_XmStringsI[74])
#endif
#ifndef XmIFOREGROUND
#define XmIFOREGROUND ((char*)&_XmStringsI[79])
#endif
#ifndef XmIHOST_NAME
#define XmIHOST_NAME ((char*)&_XmStringsI[90])
#endif
#ifndef XmILINE_NUMBER
#define XmILINE_NUMBER ((char*)&_XmStringsI[100])
#endif
#ifndef XmILIST_LENGTH
#define XmILIST_LENGTH ((char*)&_XmStringsI[112])
#endif
#ifndef XmIMODULE
#define XmIMODULE ((char*)&_XmStringsI[124])
#endif
#ifndef XmINAME
#define XmINAME ((char*)&_XmStringsI[131])
#endif
#ifndef XmINone
#define XmINone ((char*)&_XmStringsI[136])
#endif
#ifndef XmIODIF
#define XmIODIF ((char*)&_XmStringsI[141])
#endif
#ifndef XmIOWNER_OS
#define XmIOWNER_OS ((char*)&_XmStringsI[146])
#endif
#ifndef XmIPDM_EXIT_CANCEL
#define XmIPDM_EXIT_CANCEL ((char*)&_XmStringsI[155])
#endif
#ifndef XmIPDM_EXIT_ERROR
#define XmIPDM_EXIT_ERROR ((char*)&_XmStringsI[171])
#endif
#ifndef XmIPDM_EXIT_OK
#define XmIPDM_EXIT_OK ((char*)&_XmStringsI[186])
#endif
#ifndef XmIPDM_REPLY
#define XmIPDM_REPLY ((char*)&_XmStringsI[198])
#endif
#ifndef XmIPDM_START
#define XmIPDM_START ((char*)&_XmStringsI[208])
#endif
#ifndef XmIPDM_START_ERROR
#define XmIPDM_START_ERROR ((char*)&_XmStringsI[218])
#endif
#ifndef XmIPDM_START_OK
#define XmIPDM_START_OK ((char*)&_XmStringsI[234])
#endif
#ifndef XmIPDM_START_PXAUTH
#define XmIPDM_START_PXAUTH ((char*)&_XmStringsI[247])
#endif
#ifndef XmIPDM_START_VXAUTH
#define XmIPDM_START_VXAUTH ((char*)&_XmStringsI[264])
#endif
#ifndef XmIPIXEL
#define XmIPIXEL ((char*)&_XmStringsI[281])
#endif
#ifndef XmIPIXEL_SIZE
#define XmIPIXEL_SIZE ((char*)&_XmStringsI[287])
#endif
#ifndef XmIPROCEDURE
#define XmIPROCEDURE ((char*)&_XmStringsI[298])
#endif
#ifndef XmIPROCESS
#define XmIPROCESS ((char*)&_XmStringsI[308])
#endif
#ifndef XmIRESOLUTION_Y
#define XmIRESOLUTION_Y ((char*)&_XmStringsI[316])
#endif
#ifndef XmISPAN
#define XmISPAN ((char*)&_XmStringsI[329])
#endif
#ifndef XmITASK
#define XmITASK ((char*)&_XmStringsI[334])
#endif
#ifndef XmIUSER
#define XmIUSER ((char*)&_XmStringsI[339])
#endif
#ifndef XmIWM_DELETE_WINDOW
#define XmIWM_DELETE_WINDOW ((char*)&_XmStringsI[344])
#endif
#ifndef XmI_MOTIF_CURRENT_TIME
#define XmI_MOTIF_CURRENT_TIME ((char*)&_XmStringsI[361])
#endif
#ifndef XmI_MOTIF_DRAG_ATOMS
#define XmI_MOTIF_DRAG_ATOMS ((char*)&_XmStringsI[381])
#endif
#ifndef XmI_MOTIF_DRAG_INITIATOR_INFO
#define XmI_MOTIF_DRAG_INITIATOR_INFO ((char*)&_XmStringsI[399])
#endif
#ifndef XmI_MOTIF_DRAG_PROXY_WINDOW
#define XmI_MOTIF_DRAG_PROXY_WINDOW ((char*)&_XmStringsI[426])
#endif
#ifndef XmI_MOTIF_DRAG_RECEIVER_INFO
#define XmI_MOTIF_DRAG_RECEIVER_INFO ((char*)&_XmStringsI[451])
#endif
#ifndef XmI_MOTIF_DRAG_TARGETS
#define XmI_MOTIF_DRAG_TARGETS ((char*)&_XmStringsI[477])
#endif
#ifndef XmI_MOTIF_DRAG_WINDOW
#define XmI_MOTIF_DRAG_WINDOW ((char*)&_XmStringsI[497])
#endif
#ifndef XmI_MOTIF_INITIATOR
#define XmI_MOTIF_INITIATOR ((char*)&_XmStringsI[516])
#endif
#ifndef XmI_MOTIF_RECEIVER
#define XmI_MOTIF_RECEIVER ((char*)&_XmStringsI[533])
#endif
#ifndef XmI_MOTIF_SELECTION_TEXT
#define XmI_MOTIF_SELECTION_TEXT ((char*)&_XmStringsI[549])
#endif
#endif /* XMSTRINGDEFINES */

#ifdef __cplusplus
}  /* Close scope of 'extern "C"' declaration */
#endif

#endif /* _XmStrDefs_h_ */
